Profile Viewer | whylogs

Feature
Frequent items
Inf. feature type
Total count
Null fraction
Est. unique values
Data type
Data type count
Mean
Std. dev
Min
First quantile
Median
Third quantile
Max

Please select and load a JSON profile from your local drive.

#####

Item |  |  |
--- | --- | --- | ---

# Hold on! :)

It looks like your current screen size or device is not yet supported by the WhyLabs Sandbox. The Sandbox is best experienced on a desktop computer. Please try maximizing this window or switching to another device. We are working on adding support for a larger variety of devices.